@@ -18,13 +18,22 @@ sub TIEARRAY {
   my ($classname, $style, $command_or_code, %other_options) = @_;
   my $self = { value_set => 0, value => undef, style => $style };
   if ($style eq "eval") {
-    require YAML;
     $self->{code} = $command_or_code;
-    $self->{job_id} = Forks::Super::fork { %other_options, child_fh => "out",
-					     sub => sub {
-					       my @Result = $command_or_code->();
-					       print STDOUT YAML::Dump(@Result);
-					     }, _is_bg => 2 };
+    if ($other_options{"use_YAML"}) {
+      require YAML;
+      $self->{job_id} = Forks::Super::fork { %other_options, child_fh => "out",
+				  sub => sub {
+				    my @Result = $command_or_code->();
+				    print STDOUT YAML::Dump(@Result);
+				  }, _is_bg => 2, _useYAML => 1 };
+    } elsif ($other_options{"use_JSON"}) {
+      require JSON;
+      $self->{job_id} = Forks::Super::fork { %other_options, child_fh => "out",
+				  sub => sub {
+				    my @Result = $command_or_code->();
+				    print STDOUT JSON::encode_json([@Result]);
+				  }, _is_bg => 2, _useJSON => 1 };
+    }
   } elsif ($style eq "qx") {
     $self->{command} = $command_or_code;
     $self->{delimiter} = $/;
@@ -52,10 +61,27 @@ sub _retrieve_value {
     }
   }
   if ($self->{style} eq "eval") {
-    require YAML;
-    my @result = YAML::Load( join'', Forks::Super::read_stdout($self->{job_id}) );
-    $self->{value} = [ @result ];
-    $self->{value_set} = 1;
+    my $stdout = join'', Forks::Super::read_stdout($self->{job_id});
+    if ($self->{job}->{_useYAML}) {
+      require YAML;
+      my @result = YAML::Load( $stdout );
+      $self->{value} = [ @result ];
+      $self->{value_set} = 1;
+    } elsif ($self->{job}->{_useJSON}) {
+print STDERR "JSON decoding:\n------\n$stdout\n--------\n";
+      if (!defined $stdout or $stdout eq "") {
+	$self->{value_set} = 1;
+	$self->{value} = [];
+      } else {
+	require JSON;
+	my $result = JSON::decode_json( $stdout );
+	$self->{value} = [ @$result ];
+	$self->{value_set} = 1;
+      }
+    } else {
+      croak "Forks::Super::Tie::BackgroundArray: ",
+	"YAML or JSON required to use bg_eval\n";
+    }
   } elsif ($self->{style} eq "qx") {
     my @result = ();
     if (defined $self->{delimiter}) {
